@@ -148,8 +148,9 @@ COMMON_EXCEPTIONS = dict((re.compile(x), [re.compile(z) if isinstance(z, str) el
 
 	# during upgrade to UCS 5.0-0
 	("^apt.cache.FetchFailedException: E:The repository 'http://localhost/univention-repository.* Release' is not signed.", None),
-	('ImportError: No module named client', ['univention-directory-listener/system/faillog.py']),  # Bug #53290
-	(re.escape("AttributeError: 'ConfigRegistry' object has no attribute '_walk'"), ['univention-directory-listener/system/nfs-shares.py']),  # Bug #53291
+	('ImportError: No module named client', ['univention-directory-listener/system/faillog.py', 'univention-directory-listener/system/udm_extension.py', 'univention-directory-listener/system/portal_groups.py']),  # Bug #53290 Bug #53862
+	("AttributeError: 'ConfigRegistry' object has no attribute '_walk'", ['univention-directory-listener/system/nfs-shares.py']),  # Bug #53291 Bug #53862
+	("AttributeError: 'module' object has no attribute 'localization''", ['univention-directory-listener/system/app_attributes.py']),  # Bug #53862
 	("univention.lib.umc.ConnectionError: .*Could not send request.*Connection refused", ['univention-self-service-invitation']),  # Bug #53670
 
 	# updater test cases:
